"use strict";

exports.__esModule = true;
exports.sourceNodes = void 0;

var _fetchDocuments = require("./fetch-documents");

var _generateNodes = require("./generate-nodes");

var _processDocument = require("./process-document");

var _validation = require("./validation");

const sourceNodes = async ({
  actions,
  createNodeId,
  createContentDigest
}, configOptions) => {
  (0, _validation.validateConfig)(configOptions);
  configOptions.documents.forEach(async ({
    id,
    key,
    format
  }) => {
    const contentRaw = await (0, _fetchDocuments.fetchDocuments)(id);
    const options = format ? { ...configOptions,
      format
    } : configOptions;
    const formattedContent = (0, _processDocument.processDocument)(options, contentRaw);
    (0, _generateNodes.generateNodes)({
      actions,
      createNodeId,
      createContentDigest
    }, {
      key,
      content: formattedContent
    });
  });
  console.log(`[gatsby-source-copy] Fetched copy from ${configOptions.documents.length} documents`);
  return;
};

exports.sourceNodes = sourceNodes;